@@ -29,7 +29,7 @@ compile_fuzzers() {
         if [[ "$line" =~ (.*)/.*:.*(Fuzz[A-Za-z0-9]+) ]]; then
             local pkg=${BASH_REMATCH[1]}
             local func=${BASH_REMATCH[2]}
-            "$compile_fuzzer" "github.com/containerd/containerd/v2/$pkg" "$func" "fuzz_$func"
+            "$compile_fuzzer" "github.com/containerd/containerd/$pkg" "$func" "fuzz_$func"
         else
             echo "failed to parse: $line"
             exit 1
@@ -43,11 +43,11 @@ go run main.go --target_dir $SRC/containerd/images
 
 apt-get update && apt-get install -y wget
 cd $SRC
-wget --quiet https://go.dev/dl/go1.22.4.linux-amd64.tar.gz
+wget --quiet https://go.dev/dl/go1.22.9.linux-amd64.tar.gz
 
 mkdir temp-go
 rm -rf /root/.go/*
-tar -C temp-go/ -xzf go1.22.4.linux-amd64.tar.gz
+tar -C temp-go/ -xzf go1.22.9.linux-amd64.tar.gz
 mv temp-go/go/* /root/.go/
 cd $SRC/containerd
 
@@ -58,10 +58,6 @@ cd ../../
 
 rm -r vendor
 
-# Add temporary CXXFLAGS
-OLDCXXFLAGS=$CXXFLAGS
-export CXXFLAGS="$CXXFLAGS -lresolv"
-
 # Change path of socket since OSS-fuzz does not grant access to /run
 sed -i 's/\/run\/containerd/\/tmp\/containerd/g' $SRC/containerd/defaults/defaults_unix.go
 
@@ -99,6 +95,3 @@ compile_fuzzers '^func FuzzInteg.*data' compile_go_fuzzer vendor
 
 cp $SRC/containerd/contrib/fuzz/*.options $OUT/
 cp $SRC/containerd/contrib/fuzz/*.dict $OUT/
-
-# Resume CXXFLAGS
-export CXXFLAGS=$OLDCXXFLAGS
