@@ -44,7 +44,7 @@ import (
 	"github.com/containerd/containerd/pkg/transfer"
 	tarchive "github.com/containerd/containerd/pkg/transfer/archive"
 	"github.com/containerd/containerd/pkg/transfer/image"
-	"github.com/containerd/containerd/platforms"
+	"github.com/containerd/platforms"
 	"github.com/google/uuid"
 
 	digest "github.com/opencontainers/go-digest"
@@ -491,9 +491,11 @@ func createContent(size int64, seed int64) ([]byte, digest.Digest) {
 
 func createConfig(osName, archName, author string) ([]byte, digest.Digest) {
 	image := ocispec.Image{
-		OS:           osName,
-		Architecture: archName,
-		Author:       author,
+		Platform: ocispec.Platform{
+			OS:           osName,
+			Architecture: archName,
+		},
+		Author: author,
 	}
 	b, _ := json.Marshal(image)
 
